@@ -3,8 +3,7 @@
 # Also, a "module" does not necessarily mean a CPAN module, it
 # might mean a file or files or a subdirectory.
 # Most (but not all) of the modules have dual lives in the core
-# and in CPAN.  Those that have a CPAN existence, have the CPAN
-# attribute set to true.
+# and in CPAN.
 
 package Maintainers;
 
@@ -107,7 +106,7 @@ use File::Glob qw(:case);
 
 
 # Each entry in the  %Modules hash roughly represents a distribution,
-# except in the case of CPAN=1, where it *exactly* represents a single
+# except when DISTRIBUTION is set, where it *exactly* represents a single
 # CPAN distribution.
 
 # The keys of %Modules are human descriptions of the distributions, and
@@ -122,9 +121,6 @@ use File::Glob qw(:case);
 # names to be recursed down, which collectively generate a complete list
 # of the files associated with the distribution.
 
-# CPAN can be either 1 (this distribution is also available on CPAN),
-# or 0 (there is no # valid CPAN release).
-
 # UPSTREAM indicates where patches should go. undef implies
 # that this hasn't been discussed for the module at hand.
 # "blead" indicates that the copy of the module in the blead
@@ -189,7 +185,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/Archive-Extract-0.38.tar.gz',
 	'FILES'		=> q[cpan/Archive-Extract],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	'BUGS'		=> 'bug-archive-extract@rt.cpan.org',
 	},
@@ -199,7 +194,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/Archive-Tar-1.54.tar.gz',
 	'FILES'		=> q[cpan/Archive-Tar],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	'BUGS'		=> 'bug-archive-tar@rt.cpan.org',
 	},
@@ -209,7 +203,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'rgarcia',
 	'DISTRIBUTION'	=> 'SMUELLER/Attribute-Handlers-0.87.tar.gz',
 	'FILES'		=> q[dist/Attribute-Handlers],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -237,7 +230,6 @@ use File::Glob qw(:case);
 				t/system.t
 			      )
 			   ],
-	'CPAN'  	=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -247,7 +239,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'SMUELLER/AutoLoader-5.70.tar.gz',
 	'FILES'		=> q[cpan/AutoLoader],
 	'EXCLUDED'	=> [ qw( t/00pod.t ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -255,7 +246,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'smccam',
 	'FILES'		=> q[ext/B/B/Concise.pm ext/B/t/concise.t],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -265,7 +255,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'RURBAN/B-Debug-1.12.tar.gz',
 	'FILES'		=> q[cpan/B-Debug],
 	'EXCLUDED'	=> [ qw( t/coverage.html t/pod.t ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -273,7 +262,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'smccam',
 	'FILES'		=> q[dist/B-Deparse],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -283,7 +271,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'JJORE/B-Lint-1.11.tar.gz',
 	'FILES'		=> q[cpan/B-Lint],
 	'EXCLUDED'	=> [ qw( t/test.pl ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -292,7 +279,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'rgarcia',
 	'DISTRIBUTION'	=> 'RGARCIA/base-2.15.tar.gz',
 	'FILES'		=> q[dist/base],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -302,7 +288,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'TELS/math/bignum-0.23.tar.gz',
 	'FILES'		=> q[cpan/bignum],
 	'EXCLUDED'	=> [ qr{^inc/Module/}, qw(t/pod.t t/pod_cov.t) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -319,20 +304,9 @@ use File::Glob qw(:case);
 				    t/fast.t
 				)
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
-    'Class::ISA' =>
-	{
-	'MAINTAINER'	=> 'smueller',
-	'DISTRIBUTION'	=> 'SMUELLER/Class-ISA-0.36.tar.gz',
-	'FILES'		=> q[cpan/Class-ISA],
-	'CPAN'		=> 1,
-	'UPSTREAM'	=> 'cpan',
-	'DEPRECATED'	=> 5.011,
-	},
-
     'Compress::Raw::Bzip2' =>
 	{
 	'MAINTAINER'	=> 'pmqs',
@@ -342,7 +316,6 @@ use File::Glob qw(:case);
 			     qw( bzip2-src/bzip2-cpp.patch
 			     )
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -357,7 +330,6 @@ use File::Glob qw(:case);
 				 t/99pod.t
 			       )
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -373,7 +345,6 @@ use File::Glob qw(:case);
 				 eg/synopsis.pl
 			       )
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -418,7 +389,6 @@ use File::Glob qw(:case);
 				t/yaml_code.yml
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -437,7 +407,6 @@ use File::Glob qw(:case);
 				 t/032_CPANPLUS-Internals-Source-via-sqlite.t
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	'BUGS'		=> 'bug-cpanplus@rt.cpan.org',
 	},
@@ -452,7 +421,6 @@ use File::Glob qw(:case);
 			         t/99_pod_coverage.t
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -461,7 +429,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'p5p', # Not gsar. Not ilyam
 	'DISTRIBUTION'	=> 'SMUELLER/Data-Dumper-2.125.tar.gz',
 	'FILES'		=> q[dist/Data-Dumper],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -476,7 +443,6 @@ use File::Glob qw(:case);
 				 fallback.xs
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -486,7 +452,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'MHX/Devel-PPPort-3.19.tar.gz',
 	'FILES'		=> q[cpan/Devel-PPPort],
 	'EXCLUDED'	=> [ qw{PPPort.pm} ], # we use PPPort_pm.PL instead
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -496,7 +461,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'GAAS/Digest-1.16.tar.gz',
 	'FILES'		=> q[cpan/Digest],
 	'EXCLUDED'	=> [ qw{digest-bench} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -506,7 +470,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'GAAS/Digest-MD5-2.39.tar.gz',
 	'FILES'		=> q[cpan/Digest-MD5],
 	'EXCLUDED'	=> [ qw{rfc1321.txt} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -516,7 +479,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'MSHELOR/Digest-SHA-5.47.tar.gz',
 	'FILES' 	=> q[cpan/Digest-SHA],
 	'EXCLUDED'	=> [ qw{t/pod.t t/podcover.t examples/dups} ],
-	'CPAN'  	=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -525,7 +487,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'dankogai',
 	'DISTRIBUTION'	=> 'DANKOGAI/Encode-2.39.tar.gz',
 	'FILES'		=> q[cpan/Encode],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -538,7 +499,6 @@ use File::Glob qw(:case);
 			     qw{t/0-signature.t Makefile.PL MANIFEST META.yml
 			     README SIGNATURE},
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -554,7 +514,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { 't/'	=> 'lib/',
 			     'lib/'	=> 'lib/',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -563,7 +522,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kwilliams',
 	'DISTRIBUTION'	=> 'DAGOLDEN/ExtUtils-CBuilder-0.27.tar.gz',
 	'FILES'		=> q[cpan/ExtUtils-CBuilder],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -577,7 +535,6 @@ use File::Glob qw(:case);
 				 lib/Shell/Command.pm
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -594,7 +551,6 @@ use File::Glob qw(:case);
 				 examples/perl_regcomp_posix_keyword.pl
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -611,7 +567,6 @@ use File::Glob qw(:case);
 				 t/pod.t
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -623,7 +578,6 @@ use File::Glob qw(:case);
 	'EXCLUDED'	=> [ qr{^t/lib/Test/},
 			     qr{^inc/ExtUtils/},
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'first-come',
 	},
 
@@ -632,14 +586,13 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'rkobes',
 	'DISTRIBUTION'	=> 'RKOBES/ExtUtils-Manifest-1.57.tar.gz',
 	'FILES'		=> q[cpan/ExtUtils-Manifest],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
     'ExtUtils::ParseXS' =>
 	{
 	'MAINTAINER'	=> 'kwilliams',
-    'DISTRIBUTION' => 'DAGOLDEN/ExtUtils-ParseXS-2.21.tar.gz',
+    'DISTRIBUTION' => 'DAGOLDEN/ExtUtils-ParseXS-2.2205.tar.gz',
     'EXCLUDED'  => [ qw{
 	                t/bugs/RT48104.xs
 				    t/bugs/typemap
@@ -647,7 +600,6 @@ use File::Glob qw(:case);
 					t/include/nscore.h
 				   }],
 	'FILES'		=> q[cpan/ExtUtils-ParseXS],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -655,7 +607,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'perlfaq',
 	'FILES'		=> q[pod/perlfaq*],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -664,7 +615,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/File-Fetch-0.24.tar.gz',
 	'FILES'		=> q[cpan/File-Fetch],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -680,7 +630,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { ''		=> 'cpan/File-Path/lib/File/',
 			     't/'	=> 'cpan/File-Path/t/',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -693,7 +642,6 @@ use File::Glob qw(:case);
 				misc/results.txt
 			       }
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -705,7 +653,6 @@ use File::Glob qw(:case);
 	'EXCLUDED'	=> [ qw(Makefile.PL MANIFEST README META.yml),
 			     qr{^demo/}
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -740,7 +687,6 @@ use File::Glob qw(:case);
 			     'perlfilter.pod' => 'pod/perlfilter.pod',
 			     ''		      => 'cpan/Filter-Util-Call/',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -757,7 +703,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { ''		       => 'cpan/Getopt-Long/',
 			     'lib/newgetopt.pl' => 'lib/newgetopt.pl',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -769,7 +714,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'p5p',
 	'DISTRIBUTION'	=> 'SBURKE/I18N-LangTags-0.35.tar.gz',
 	'FILES'		=> q[dist/I18N-LangTags],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -778,7 +722,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'ilyaz',
 	'DISTRIBUTION'	=> 'ILYAZ/modules/if-0.0401.tar.gz',
 	'FILES'		=> q[cpan/if],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -788,7 +731,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'GBARR/IO-1.25.tar.gz',
 	'FILES'		=> q[dist/IO/],
 	'EXCLUDED'	=> [ qw{t/test.pl}, ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -798,7 +740,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'PMQS/IO-Compress-2.021.tar.gz',
 	'FILES'		=> q[cpan/IO-Compress],
 	'EXCLUDED'	=> [ qr{t/Test/} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -807,16 +748,14 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'tomhughes',
 	'DISTRIBUTION'	=> 'TOMHUGHES/IO-Zlib-1.10.tar.gz',
 	'FILES'		=> q[cpan/IO-Zlib],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
     'IPC::Cmd' =>
 	{
 	'MAINTAINER'	=> 'kane',
-	'DISTRIBUTION'	=> 'BINGOS/IPC-Cmd-0.54.tar.gz',
+	'DISTRIBUTION'	=> 'BINGOS/IPC-Cmd-0.58.tar.gz',
 	'FILES'		=> q[cpan/IPC-Cmd],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -826,7 +765,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'MHX/IPC-SysV-2.01.tar.gz',
 	'FILES'		=> q[cpan/IPC-SysV],
 	'EXCLUDED'	=> [ qw{const-c.inc const-xs.inc} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -836,7 +774,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'SMUELLER/lib-0.62.tar.gz',
 	'FILES'		=> q[dist/lib/],
 	'EXCLUDED'	=> [ qw{forPAUSE/lib.pm t/00pod.t} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -846,16 +783,16 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'GBARR/libnet-1.22.tar.gz',
 	'FILES'		=> q[cpan/libnet],
 	'EXCLUDED'	=> [ qw{Configure install-nomake} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
     'Locale-Codes' =>
 	{
 	'MAINTAINER'	=> 'sbeck',
-	'DISTRIBUTION'	=> 'NEILB/Locale-Codes-2.07.tar.gz',
+	'DISTRIBUTION'	=> 'SBECK/Locale-Codes-3.12.tar.gz',
 	'FILES'		=> q[cpan/Locale-Codes],
-	'CPAN'		=> 1,
+	'EXCLUDED'	=> [ qw{t/pod_coverage.t t/pod.t}, qr{^t/runtests},
+			     qr{^internal/}, qr{^examples/} ],
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -865,7 +802,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'FERREIRA/Locale-Maketext-1.13.tar.gz',
 	'FILES'		=> q[dist/Locale-Maketext],
 	'EXCLUDED'	=> [ qw{perlcriticrc t/00_load.t t/pod.t} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -875,7 +811,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'JESSE/Locale-Maketext-Simple-0.21.tar.gz',
 	'FILES'		=> q[cpan/Locale-Maketext-Simple],
 	'EXCLUDED'	=> [ qr{^inc/} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -884,7 +819,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'KANE/Log-Message-0.02.tar.gz',
 	'FILES'		=> q[cpan/Log-Message],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -893,7 +827,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/Log-Message-Simple-0.06.tar.gz',
 	'FILES'		=> q[cpan/Log-Message-Simple],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -901,7 +834,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'lwall',
 	'FILES'		=> q[mad],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -916,7 +848,6 @@ use File::Glob qw(:case);
 				t/pod_cov.t
 			       }
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -944,7 +875,6 @@ use File::Glob qw(:case);
 			     'lib/Math/BigInt/FastCalc.pm'
 				    => 'cpan/Math-BigInt-FastCalc/FastCalc.pm',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -959,7 +889,6 @@ use File::Glob qw(:case);
 				t/pod_cov.t
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -974,7 +903,6 @@ use File::Glob qw(:case);
 				t/pod-coverage.t
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -989,18 +917,16 @@ use File::Glob qw(:case);
 				Memoize/Saves.pm
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
     'MIME::Base64' =>
 	{
 	'MAINTAINER'	=> 'gaas',
-	'DISTRIBUTION'	=> 'GAAS/MIME-Base64-3.08.tar.gz',
+	'DISTRIBUTION'	=> 'GAAS/MIME-Base64-3.09.tar.gz',
 	'FILES'		=> q[cpan/MIME-Base64],
 	'EXCLUDED'	=> [ qw{ t/bad-sv.t }, ],
-	'CPAN'		=> 1,
-	'UPSTREAM'	=> undef,
+	'UPSTREAM'	=> 'cpan',
 	},
 
     'Module::Build' =>
@@ -1010,16 +936,14 @@ use File::Glob qw(:case);
 	'FILES'		=> q[cpan/Module-Build],
 	'EXCLUDED'	=> [ qw{ t/par.t t/signature.t },
 			     qr!^contrib/!,  qr!^devtools! ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
     'Module::CoreList' =>
 	{
 	'MAINTAINER'	=> 'rgarcia',
-	'DISTRIBUTION'	=> 'BINGOS/Module-CoreList-2.36.tar.gz',
+	'DISTRIBUTION'	=> 'BINGOS/Module-CoreList-2.23.tar.gz',
 	'FILES'		=> q[dist/Module-CoreList],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1028,7 +952,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'KANE/Module-Load-0.16.tar.gz',
 	'FILES'		=> q[cpan/Module-Load],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1037,7 +960,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/Module-Load-Conditional-0.38.tar.gz',
 	'FILES'		=> q[cpan/Module-Load-Conditional],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1046,7 +968,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/Module-Loaded-0.06.tar.gz',
 	'FILES'		=> q[cpan/Module-Loaded],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1055,7 +976,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'simonw',
 	'DISTRIBUTION'	=> 'SIMONW/Module-Pluggable-3.9.tar.gz',
 	'FILES'		=> q[cpan/Module-Pluggable],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1064,7 +984,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'smpeters',
 	'DISTRIBUTION'	=> 'SMPETERS/Net-Ping-2.36.tar.gz',
 	'FILES'		=> q[dist/Net-Ping],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1074,7 +993,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'FLORA/NEXT-0.64.tar.gz',
 	'FILES'		=> q[cpan/NEXT],
 	'EXCLUDED'	=> [ qr{^demo/} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1083,7 +1001,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'BINGOS/Object-Accessor-0.36.tar.gz',
 	'FILES'		=> q[cpan/Object-Accessor],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1092,7 +1009,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'KANE/Package-Constants-0.02.tar.gz',
 	'FILES'		=> q[cpan/Package-Constants],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1104,7 +1020,6 @@ use File::Glob qw(:case);
 	# the tarball. Russell's Paradox eat your heart out.
 	'EXCLUDED'	=> [ qw( Params-Check-0.26.tar.gz ) ],
 	'FILES'		=> q[cpan/Params-Check],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1113,7 +1028,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'corion',
 	'DISTRIBUTION'	=> 'CORION/parent-0.223.tar.gz',
 	'FILES'		=> q[cpan/parent],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1123,7 +1037,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'SMUELLER/Parse-CPAN-Meta-1.40.tar.gz',
 	'FILES'		=> q[cpan/Parse-CPAN-Meta],
 	'EXCLUDED'	=> [ qw( t/97_meta.t t/98_pod.t t/99_pmv.t ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	# NOTE: 'perl uupacktool.pl t/data/utf_16_le_bom.yml.packed'
 	# run by hand after import, as the core's test harness doesn't
@@ -1136,7 +1049,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'SMUELLER/PathTools-3.31.tar.gz',
 	'FILES'		=> q[cpan/Cwd],
 	'EXCLUDED'	=> [ qr{^t/lib/Test/} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> "cpan",
 	# NOTE: PathTools is in cpan/Cwd/ because it contains Cwd.xs and
 	# something, possibly Makefile.SH, makes an assumption that the
@@ -1147,7 +1059,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'pvhp',
 	'FILES'		=> q[pod/perlebcdic.pod],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1155,7 +1066,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'p5p',
 	'FILES'		=> q[ext/PerlIO],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1164,7 +1074,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'elizabeth',
 	'DISTRIBUTION'	=> 'ELIZABETH/PerlIO-via-QuotedPrint-0.06.tar.gz',
 	'FILES'		=> q[cpan/PerlIO-via-QuotedPrint],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1172,7 +1081,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'laun',
 	'FILES'		=> q[pod/perlpacktut.pod],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1180,7 +1088,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'sburke',
 	'FILES'		=> q[pod/perlpodspec.pod],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1189,7 +1096,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'abigail',
 	'FILES'		=> q[pod/perlrecharclass.pod
 			     pod/perlrebackslash.pod],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1198,7 +1104,6 @@ use File::Glob qw(:case);
 	{
 	MAINTAINER	=> 'avar',
 	FILES		=> q[pod/perlreapi.pod],
-	CPAN		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1206,7 +1111,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'mjd',
 	'FILES'		=> q[pod/perlreftut.pod],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1214,7 +1118,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'elizabeth',
 	'FILES'		=> q[pod/perlthrtut.pod],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1223,7 +1126,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'arandal',
 	'DISTRIBUTION'	=> 'SBURKE/Pod-Escapes-1.04.tar.gz',
 	'FILES'		=> q[cpan/Pod-Escapes],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1238,7 +1140,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { '' => 'cpan/Pod-LaTeX/',
 			     'pod2latex.PL' => 'pod/pod2latex.PL',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1255,7 +1156,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { '' => 'cpan/Pod-Parser/',
 			     'scripts/' => 'pod/',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1277,21 +1177,9 @@ use File::Glob qw(:case);
 	'MAP'		=> { '' => 'dist/Pod-Perldoc/',
 			     'lib/perldoc.pod' => 'pod/perldoc.pod',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
-    'Pod::Plainer' =>
-	{
-	'DISTRIBUTION'	=> 'RMBARKER/Pod-Plainer-1.02.tar.gz',
-	'MAINTAINER'	=> 'rmbarker',
-	'FILES'		=> q[dist/Pod-Plainer],
-	'CPAN'		=> 1,
-	'UPSTREAM'	=> 'blead',
-	'EXCLUDED'	=> [ qw(t/pod.t t/pod-coverage.t) ],
-	'DEPRECATED'	=> 5.011,
-	},
-
     'Pod::Simple' =>
 	{
 	'MAINTAINER'	=> 'arandal',
@@ -1302,7 +1190,6 @@ use File::Glob qw(:case);
 	# have been in blead a long time. I'm going to assume then that
 	# the blead versions of these two files are authoritative - DAPM
 	'EXCLUDED'	=> [ qw( lib/perlpod.pod lib/perlpodspec.pod ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1317,7 +1204,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { '' => 'cpan/podlators/',
 			     'scripts/' => 'pod/',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1326,21 +1212,19 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'rgarcia',
 	'DISTRIBUTION'	=> 'RGARCIA/Safe-2.22.tar.gz',
 	'FILES'		=> q[dist/Safe],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
     'Scalar-List-Utils' =>
 	{
 	'MAINTAINER'	=> 'gbarr',
-	'DISTRIBUTION'	=> 'GBARR/Scalar-List-Utils-1.21.tar.gz',
+	'DISTRIBUTION'	=> 'GBARR/Scalar-List-Utils-1.23.tar.gz',
 	# Note that perl uses its own version of Makefile.PL
 	'FILES'		=> q[cpan/List-Util],
 	'EXCLUDED'	=> [ qr{^inc/Module/},
 			     qr{^inc/Test/},
 			     qw{ mytypemap },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1350,7 +1234,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'SMUELLER/SelfLoader-1.17.tar.gz',
 	'FILES'		=> q[dist/SelfLoader],
 	'EXCLUDED'	=> [ qw{ t/00pod.t } ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1371,20 +1254,9 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'AMS/Storable-2.21.tar.gz',
 	'FILES'		=> q[dist/Storable],
 	'EXCLUDED'	=> [ qr{^t/Test/} ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
-    'Switch' =>
-	{
-	'MAINTAINER'	=> 'rgarcia',
-	'DISTRIBUTION'	=> 'RGARCIA/Switch-2.15.tar.gz',
-	'FILES'		=> q[dist/Switch],
-	'CPAN'		=> 1,
-	'UPSTREAM'	=> 'blead',
-	'DEPRECATED'	=> 5.011,
-	},
-
     'Sys::Syslog' =>
 	{
 	'MAINTAINER'	=> 'saper',
@@ -1400,7 +1272,6 @@ use File::Glob qw(:case);
 				win32/PerlLog.RES
 			       },
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1410,7 +1281,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'RRA/ANSIColor-2.02.tar.gz',
 	'FILES'		=> q[cpan/Term-ANSIColor],
 	'EXCLUDED'	=> [ qr{^tests/}, qw(t/pod-spelling.t t/pod.t) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1419,7 +1289,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'jstowe',
 	'DISTRIBUTION'	=> 'JSTOWE/Term-Cap-1.12.tar.gz',
 	'FILES'		=> q[cpan/Term-Cap],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1428,7 +1297,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'kane',
 	'DISTRIBUTION'	=> 'KANE/Term-UI-0.20.tar.gz',
 	'FILES'		=> q[cpan/Term-UI],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1437,7 +1305,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'jesse',
 	'DISTRIBUTION'	=> 'JESSE/Test-1.25_02.tar.gz',
 	'FILES'		=> q[cpan/Test],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1456,7 +1323,6 @@ use File::Glob qw(:case);
 				t/lib/if.pm
 			       }
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1475,7 +1341,6 @@ use File::Glob qw(:case);
 				lib/Test/Builder/IO/Scalar.pm
 			       }
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1485,7 +1350,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'ADAMK/Text-Balanced-2.02.tar.gz',
 	'FILES'		=> q[cpan/Text-Balanced],
 	'EXCLUDED'	=> [ qw( t/97_meta.t t/98_pod.t t/99_pmv.t ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1500,7 +1364,6 @@ use File::Glob qw(:case);
 			     'ParseWords.pm' => 'cpan/Text-ParseWords/lib/Text/ParseWords.pm',
 			     ''              => 'cpan/Text-ParseWords/',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1515,7 +1378,6 @@ use File::Glob qw(:case);
 			     # considerably over the years
 	                     'test.pl'        => 'cpan/Text-Soundex/t/Soundex.t',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1525,7 +1387,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'MUIR/modules/Text-Tabs+Wrap-2009.0305.tar.gz',
 	'FILES'		=> q[cpan/Text-Tabs],
 	'EXCLUDED'	=> [ qw( t/dnsparks.t ) ], # see af6492bf9e
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1539,7 +1400,6 @@ use File::Glob qw(:case);
 				t/99_pod.t
 				t/test.pl
 			       ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1553,35 +1413,32 @@ use File::Glob qw(:case);
 				t/99_pod.t
 				t/test.pl
 			       ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
     'threads' =>
 	{
 	'MAINTAINER'	=> 'jdhedden',
-	'DISTRIBUTION'	=> 'JDHEDDEN/threads-1.75.tar.gz',
+	'DISTRIBUTION'	=> 'JDHEDDEN/threads-1.77.tar.gz',
 	'FILES'		=> q[dist/threads],
-	'EXCLUDED'	=> [ qw(examples/pool.pl
-				t/pod.t
+	'EXCLUDED'	=> [ qr{^examples/},
+			     qw(t/pod.t
 				t/test.pl
 				threads.h
 			       ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
     'threads::shared' =>
 	{
 	'MAINTAINER'	=> 'jdhedden',
-	'DISTRIBUTION'	=> 'JDHEDDEN/threads-shared-1.32.tar.gz',
+	'DISTRIBUTION'	=> 'JDHEDDEN/threads-shared-1.33.tar.gz',
 	'FILES'		=> q[dist/threads-shared],
 	'EXCLUDED'	=> [ qw(examples/class.pl
 				shared.h
 				t/pod.t
 				t/test.pl
 			       ) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1590,7 +1447,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'mjd',
 	'DISTRIBUTION'	=> 'MJD/Tie-File-0.96.tar.gz',
 	'FILES'		=> q[cpan/Tie-File],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1599,7 +1455,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'nuffin',
 	'DISTRIBUTION'	=> 'NUFFIN/Tie-RefHash-1.38.tar.gz',
 	'FILES'		=> q[cpan/Tie-RefHash],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1608,7 +1463,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'zefram',
 	'DISTRIBUTION'	=> 'JHI/Time-HiRes-1.9719.tar.gz',
 	'FILES'		=> q[cpan/Time-HiRes],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1618,7 +1472,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'DROLSKY/Time-Local-1.1901.tar.gz',
 	'FILES'		=> q[ext/Time-Local],
 	'EXCLUDED'	=> [ qw(t/pod-coverage.t t/pod.t) ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	# Currently Time::Local is no longer backwards compatible with Pre-5.11 perls
 	# the version in core has now deviated from the CPAN version. To re-dual-life
@@ -1630,7 +1483,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'msergeant',
 	'DISTRIBUTION'	=> 'MSERGEANT/Time-Piece-1.15.tar.gz',
 	'FILES'		=> q[cpan/Time-Piece],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1643,7 +1495,6 @@ use File::Glob qw(:case);
 	'EXCLUDED'	=> [ qr{X$},
 			     qw{disableXS enableXS }
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'first-come',
 	},
 
@@ -1653,7 +1504,6 @@ use File::Glob qw(:case);
 	'DISTRIBUTION'	=> 'SADAHIRO/Unicode-Normalize-1.03.tar.gz',
 	'FILES'		=> q[cpan/Unicode-Normalize],
 	'EXCLUDED'	=> [ qw{MANIFEST.N Normalize.pmN disableXS enableXS }],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'first-come',
 	},
 
@@ -1670,7 +1520,6 @@ use File::Glob qw(:case);
 	'MAP'		=> { 'lib/'	      => 'lib/',
 			     't/coretests.pm' => 'lib/version.t',
 			   },
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1678,7 +1527,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'craig',
 	'FILES'		=> q[vms configure.com README.vms],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1686,7 +1534,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'craig',
 	'FILES'		=> q[ext/VMS-DCLsym],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1694,7 +1541,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'craig',
 	'FILES'		=> q[ext/VMS-Stdio],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1706,7 +1552,6 @@ use File::Glob qw(:case);
 			     lib/warnings
 			     t/lib/warnings
 			    ],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1714,7 +1559,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'jand',
 	'FILES'		=> q[win32 t/win32 README.win32 ext/Win32CORE],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1723,7 +1567,6 @@ use File::Glob qw(:case);
 	'MAINTAINER'	=> 'jand',
 	'DISTRIBUTION'	=> "JDB/Win32-0.39.tar.gz",
 	'FILES'		=> q[cpan/Win32],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1735,7 +1578,6 @@ use File::Glob qw(:case);
 	'EXCLUDED'	=> [ qr{^ex/},
 			     qw{t/pod.t},
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'cpan',
 	},
 
@@ -1743,7 +1585,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'zefram',
 	'FILES'		=> q[ext/XS-APItest-KeywordRPN],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1758,7 +1599,6 @@ use File::Glob qw(:case);
 				t/portfs.t
 				XSLoader.pm}, # we use XSLoader_pm.PL
 			   ],
-	'CPAN'		=> 1,
 	'UPSTREAM'	=> 'blead',
 	},
 
@@ -1766,7 +1606,6 @@ use File::Glob qw(:case);
 	{
 	'MAINTAINER'	=> 'laun',
 	'FILES'		=> q[x2p/s2p.PL],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 
@@ -1986,9 +1825,13 @@ use File::Glob qw(:case);
 				lib/vars{.pm,.t,_carp.t}
 				lib/vmsish.{pm,t}
 			    ],
-	'CPAN'		=> 0,
 	'UPSTREAM'	=> undef,
 	},
 );
 
+# legacy CPAN flag
+for (values %Modules) {
+    $_->{CPAN} = !!$_->{DISTRIBUTION};
+}
+
 1;
