@@ -33,8 +33,8 @@ apirevision=''
 apisubversion=''
 apiversion=''
 ar='arm-epoc-pe-ar'
-archlib='/usr/lib/perl/5.12.5/epoc'
-archlibexp='/usr/lib/perl/5.12.5/epoc'
+archlib='/usr/lib/perl/5.13.1/epoc'
+archlibexp='/usr/lib/perl/5.13.1/epoc'
 archname64=''
 archname='epoc'
 archobjs='epoc.o epocish.o epoc_stubs.o'
@@ -762,8 +762,8 @@ pmake=''
 pr=''
 prefix=''
 prefixexp=''
-privlib='/usr/lib/perl/5.12.5'
-privlibexp='/usr/lib/perl/5.12.5'
+privlib='/usr/lib/perl/5.13.1'
+privlibexp='/usr/lib/perl/5.13.1'
 procselfexe=''
 prototype='define'
 ptrsize='4'
@@ -822,11 +822,11 @@ sig_num='0'
 sig_num_init='0, 0'
 sig_size='1'
 signal_t='void'
-sitearch='/usr/lib/perl/site_perl/5.12.5/epoc'
-sitearchexp='/usr/lib/perl/site_perl/5.12.5/epoc'
-sitelib='/usr/lib/perl/site_perl/5.12.5/'
+sitearch='/usr/lib/perl/site_perl/5.13.1/epoc'
+sitearchexp='/usr/lib/perl/site_perl/5.13.1/epoc'
+sitelib='/usr/lib/perl/site_perl/5.13.1/'
 sitelib_stem='/usr/lib/perl/site_perl'
-sitelibexp='/usr/lib/perl/site_perl/5.12.5/'
+sitelibexp='/usr/lib/perl/site_perl/5.13.1/'
 siteprefix=''
 siteprefixexp=''
 sizesize='4'
@@ -910,7 +910,7 @@ vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.12.5'
+version='5.13.1'
 versiononly='undef'
 vi=''
 voidflags='15'
@@ -933,10 +933,10 @@ config_arg9=''
 config_arg10=''
 config_arg11=''
 PERL_REVISION=5
-PERL_VERSION=12
-PERL_SUBVERSION=5
+PERL_VERSION=13
+PERL_SUBVERSION=1
 PERL_API_REVISION=5
-PERL_API_VERSION=12
+PERL_API_VERSION=13
 PERL_API_SUBVERSION=0
 PERL_CONFIG_SH=true
 # Variables propagated from previous config.sh file.
@@ -1043,7 +1043,7 @@ vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.12.5'
+version='5.13.1'
 vi=''
 voidflags='15'
 xlibpth=''
@@ -1065,10 +1065,10 @@ config_arg9=''
 config_arg10=''
 config_arg11=''
 PERL_REVISION=5
-PERL_VERSION=12
-PERL_SUBVERSION=5
+PERL_VERSION=13
+PERL_SUBVERSION=1
 PERL_API_REVISION=5
-PERL_API_VERSION=12
+PERL_API_VERSION=13
 PERL_API_SUBVERSION=0
 CONFIGDOTSH=true
 # Variables propagated from previous config.sh file.
@@ -1167,16 +1167,16 @@ d_SCNfldbl='undef'
 d_perl_otherlibdirs='undef'
 nvsize='16'
 issymlink=''
-installarchlib='/home/of/PERL/perl/lib/5.12.5/epoc'
+installarchlib='/home/of/PERL/perl/lib/5.13.1/epoc'
 installbin='/home/of/PERL/System/Programs/'
 installman1dir='/home/of/PERL/man1'
 installman3dir='/home/of/PERL/man3'
 installprefix=''
 installprefixexp=''
-installprivlib='/home/of/PERL/perl/lib/5.12.5/'
+installprivlib='/home/of/PERL/perl/lib/5.13.1/'
 installscript='/home/of/PERL/bin/'
-installsitearch='/home/of/PERL/site/lib/site_perl/5.12.5/epoc'
-installsitelib='/home/of/PERL/perl/lib/site_perl/5.12.5'
+installsitearch='/home/of/PERL/site/lib/site_perl/5.13.1/epoc'
+installsitelib='/home/of/PERL/perl/lib/site_perl/5.13.1'
 installstyle=''
 installusrbinperl='undef'
 installvendorlib=''
@@ -1190,6 +1190,8 @@ d_builtin_expect='undef'
 d_ctermid='undef'
 d_inc_version_list='undef'
 d_libm_lib_version='0'
+d_prctl='undef'
+d_prctl_set_name='undef'
 d_printf_format_null='undef'
 d_pseudofork='undef'
 d_signbit='undef'
