@@ -43,6 +43,9 @@ PERLVAR(Istack_base,	SV **)
 PERLVAR(Istack_max,	SV **)
 
 PERLVAR(Iscopestack,	I32 *)		/* scopes we've ENTERed */
+/* name of the scopes we've ENTERed. Only used with -DDEBUGGING, but needs to be
+   present always, as -DDEUBGGING must be binary compatible with non.  */
+PERLVARI(Iscopestack_name, const char * *, NULL)
 PERLVAR(Iscopestack_ix,	I32)
 PERLVAR(Iscopestack_max,I32)
 
@@ -123,6 +126,7 @@ PERLVAR(Idefstash,	HV *)		/* main symbol table */
 PERLVAR(Icurstash,	HV *)		/* symbol table for current package */
 
 PERLVAR(Irestartop,	OP *)		/* propagating an error from croak? */
+PERLVAR(Irestartjmpenv,	JMPENV *)	/* target frame for longjmp in die */
 PERLVAR(Icurcop,	COP *)
 PERLVAR(Icurstack,	AV *)		/* THE STACK */
 PERLVAR(Icurstackinfo,	PERL_SI *)	/* current stack + context */
@@ -516,6 +520,9 @@ PERLVAR(Iutf8_alnum,	SV *)
 PERLVAR(Iutf8_ascii,	SV *)
 PERLVAR(Iutf8_alpha,	SV *)
 PERLVAR(Iutf8_space,	SV *)
+PERLVAR(Iutf8_perl_space,	SV *)
+PERLVAR(Iutf8_perl_word,	SV *)
+PERLVAR(Iutf8_posix_digit,	SV *)
 PERLVAR(Iutf8_cntrl,	SV *)
 PERLVAR(Iutf8_graph,	SV *)
 PERLVAR(Iutf8_digit,	SV *)
@@ -525,6 +532,16 @@ PERLVAR(Iutf8_print,	SV *)
 PERLVAR(Iutf8_punct,	SV *)
 PERLVAR(Iutf8_xdigit,	SV *)
 PERLVAR(Iutf8_mark,	SV *)
+PERLVAR(Iutf8_X_begin,	SV *)
+PERLVAR(Iutf8_X_extend,	SV *)
+PERLVAR(Iutf8_X_prepend,	SV *)
+PERLVAR(Iutf8_X_non_hangul,	SV *)
+PERLVAR(Iutf8_X_L,	SV *)
+PERLVAR(Iutf8_X_LV,	SV *)
+PERLVAR(Iutf8_X_LVT,	SV *)
+PERLVAR(Iutf8_X_T,	SV *)
+PERLVAR(Iutf8_X_V,	SV *)
+PERLVAR(Iutf8_X_LV_LVT_V,	SV *)
 PERLVAR(Iutf8_toupper,	SV *)
 PERLVAR(Iutf8_totitle,	SV *)
 PERLVAR(Iutf8_tolower,	SV *)
